﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Text;
using Virinco.WATS.Interface;

namespace MyNewConverter
{
    /// <summary>
    /// This converter shows a very simple example on how to use the WATS Client converter plugin.
    /// </summary>
    class MyConverter : IReportConverter 
    {
        private string someArgumentYouNeed="Default";   //Used to store the arguments in the class (optional)
        private string operationTypeCode="10";          //10=Software Debug
        
        /// <summary>
        /// Constructor (optional) will transfer any arguments from Converters.xml
        /// </summary>
        /// <param name="args">String dictionary</param>
        public MyConverter(IDictionary<string, string> args)
        {
            if (args != null && args.ContainsKey("SomeArgument"))
                someArgumentYouNeed = args["SomeArgument"];
            if (args != null && args.ContainsKey("OperatironTypeCode"))
                operationTypeCode = args["OperationTypeCode"];
        }

        public void CleanUp()
        {
            //If needed, will be called if the WATS client service is stopped
        }

        /// <summary>
        /// This is the main interface call and the only thing you have to implement
        /// </summary>
        /// <param name="api">An open WATS TDM api (see own documentation)</param>
        /// <param name="file">A file stream to a file placed in the drop folder defined by convertes.xml</param>
        /// <returns>An UUT or UUR report (can also be null if desired, the conversion code must then handle submit</returns>
        /// <remarks>
        /// This example is made simple and assumes that the file is a tab delimited file with one test per line
        /// File format: DateTime(0),SerialNumber(1),PartNumber(2),Revision(3),NumericTestValue(4),LoLimit(5),HiLimit(6)
        /// </remarks>
        public Report ImportReport(TDM api, System.IO.Stream file)
        {
            int lineCount = 0;
            api.TestMode = TestModeType.Active; //This will make the API decide from limits if tests have passed / failed
            try
            {
                using (StreamReader reader = new StreamReader(file))
                {
                    while (!reader.EndOfStream)
                    {
                        string line = reader.ReadLine(); lineCount++;
                        string[] fields = line.Split(new char[] { '\t' });
                        UUTReport uutReport = api.CreateUUTReport("sysoper", fields[2], fields[3], fields[1], "10", "MyNewConverter", "0.1");
                        uutReport.StartDateTime = DateTime.ParseExact(fields[0], "yyyy-MM-dd HH:mm:ss", CultureInfo.InvariantCulture);
                        uutReport.AddMiscUUTInfo("SomeArgument", someArgumentYouNeed);
                        uutReport.GetRootSequenceCall().AddNumericLimitStep("NumericTest").AddTest(double.Parse(fields[4]), CompOperatorType.GELE, double.Parse(fields[5]), double.Parse(fields[6]), "V");
                        api.Submit(SubmitMethod.Automatic, uutReport);
                    }
                }
            }
            catch (Exception ex)
            {
                StreamWriter errorlog = new StreamWriter(api.ConversionSource.ErrorLog); //Will place the file in an error catalog
                errorlog.WriteLine("Error in file {0}, line {1}: {2}", api.ConversionSource.SourceFile.Name, lineCount, ex.Message);
                errorlog.Flush();
            }
            return null; //If the file contains just one report, the report can be returned to the WATS Client her for submission (No submit required).
        }
    }
}
